"""CAMEL: Communicative Agents for "Mind" Exploration

Implementation of the CAMEL paper (arxiv:2303.17760)
https://arxiv.org/abs/2303.17760

CAMEL is a framework for building communicative agents that can
collaborate through role-playing to solve complex tasks.
"""

from .agent import RolePlayingAgent, AgentRole
from .conversation import Conversation, Message, MessageRole
from .society import CAMELSociety, SocietyResult
from .types import Task, Role, AgentType, TaskSpec, DEFAULT_ROLES

__version__ = "0.1.0"
__all__ = [
    "RolePlayingAgent",
    "AgentRole",
    "Conversation",
    "Message",
    "MessageRole",
    "CAMELSociety",
    "SocietyResult",
    "Task",
    "Role",
    "AgentType",
    "TaskSpec",
    "DEFAULT_ROLES",
]